All Classes and Interfaces

Classes
Class
Description
gRPC callable factory implementation for the LanguageService service API.
gRPC callable factory implementation for the LanguageService service API.
gRPC callable factory implementation for the LanguageService service API.
gRPC stub implementation for the LanguageService service API.
gRPC stub implementation for the LanguageService service API.
gRPC stub implementation for the LanguageService service API.
REST callable factory implementation for the LanguageService service API.
REST callable factory implementation for the LanguageService service API.
REST callable factory implementation for the LanguageService service API.
REST stub implementation for the LanguageService service API.
REST stub implementation for the LanguageService service API.
REST stub implementation for the LanguageService service API.
Service Description: Provides text analysis operations such as sentiment analysis and entity recognition.
Service Description: Provides text analysis operations such as sentiment analysis and entity recognition.
Service Description: Provides text analysis operations such as sentiment analysis and entity recognition.
Settings class to configure an instance of LanguageServiceClient.
Settings class to configure an instance of LanguageServiceClient.
Settings class to configure an instance of LanguageServiceClient.
Builder for LanguageServiceSettings.
Builder for LanguageServiceSettings.
Builder for LanguageServiceSettings.
Base stub class for the LanguageService service API.
Base stub class for the LanguageService service API.
Base stub class for the LanguageService service API.
Settings class to configure an instance of LanguageServiceStub.
Settings class to configure an instance of LanguageServiceStub.
Settings class to configure an instance of LanguageServiceStub.
Builder for LanguageServiceStubSettings.
Builder for LanguageServiceStubSettings.
Builder for LanguageServiceStubSettings.