Class LanguageServiceClient

java.lang.Object
com.google.cloud.language.v1beta2.LanguageServiceClient
All Implemented Interfaces:
BackgroundResource, AutoCloseable

@BetaApi @Generated("by gapic-generator-java") public class LanguageServiceClient extends Object implements BackgroundResource
Service Description: Provides text analysis operations such as sentiment analysis and entity recognition.

This class provides the ability to make remote calls to the backing service through method calls that map to API methods. Sample code to get started:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
   Document document = Document.newBuilder().build();
   AnalyzeSentimentResponse response = languageServiceClient.analyzeSentiment(document);
 }
 

Note: close() needs to be called on the LanguageServiceClient object to clean up resources such as threads. In the example above, try-with-resources is used, which automatically calls close().

Methods
Method Description Method Variants

AnalyzeSentiment

Analyzes the sentiment of the provided text.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • analyzeSentiment(AnalyzeSentimentRequest request)

"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.

  • analyzeSentiment(Document document)

  • analyzeSentiment(Document document, EncodingType encodingType)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • analyzeSentimentCallable()

AnalyzeEntities

Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • analyzeEntities(AnalyzeEntitiesRequest request)

"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.

  • analyzeEntities(Document document)

  • analyzeEntities(Document document, EncodingType encodingType)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • analyzeEntitiesCallable()

AnalyzeEntitySentiment

Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • analyzeEntitySentiment(AnalyzeEntitySentimentRequest request)

"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.

  • analyzeEntitySentiment(Document document)

  • analyzeEntitySentiment(Document document, EncodingType encodingType)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • analyzeEntitySentimentCallable()

AnalyzeSyntax

Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • analyzeSyntax(AnalyzeSyntaxRequest request)

"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.

  • analyzeSyntax(Document document)

  • analyzeSyntax(Document document, EncodingType encodingType)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • analyzeSyntaxCallable()

ClassifyText

Classifies a document into categories.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • classifyText(ClassifyTextRequest request)

"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.

  • classifyText(Document document)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • classifyTextCallable()

ModerateText

Moderates a document for harmful and sensitive categories.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • moderateText(ModerateTextRequest request)

"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.

  • moderateText(Document document)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • moderateTextCallable()

AnnotateText

A convenience method that provides all syntax, sentiment, entity, and classification features in one call.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • annotateText(AnnotateTextRequest request)

"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.

  • annotateText(Document document, AnnotateTextRequest.Features features)

  • annotateText(Document document, AnnotateTextRequest.Features features, EncodingType encodingType)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • annotateTextCallable()

See the individual methods for example code.

Many parameters require resource names to be formatted in a particular way. To assist with these names, this class includes a format method for each type of name, and additionally a parse method to extract the individual identifiers contained within names that are returned.

This class can be customized by passing in a custom instance of LanguageServiceSettings to create(). For example:

To customize credentials:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 LanguageServiceSettings languageServiceSettings =
     LanguageServiceSettings.newBuilder()
         .setCredentialsProvider(FixedCredentialsProvider.create(myCredentials))
         .build();
 LanguageServiceClient languageServiceClient =
     LanguageServiceClient.create(languageServiceSettings);
 

To customize the endpoint:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 LanguageServiceSettings languageServiceSettings =
     LanguageServiceSettings.newBuilder().setEndpoint(myEndpoint).build();
 LanguageServiceClient languageServiceClient =
     LanguageServiceClient.create(languageServiceSettings);
 

To use REST (HTTP1.1/JSON) transport (instead of gRPC) for sending and receiving requests over the wire:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 LanguageServiceSettings languageServiceSettings =
     LanguageServiceSettings.newHttpJsonBuilder().build();
 LanguageServiceClient languageServiceClient =
     LanguageServiceClient.create(languageServiceSettings);
 

Please refer to the GitHub repository's samples for more quickstart code snippets.

  • Constructor Details

    • LanguageServiceClient

      protected LanguageServiceClient(LanguageServiceSettings settings) throws IOException
      Constructs an instance of LanguageServiceClient, using the given settings. This is protected so that it is easy to make a subclass, but otherwise, the static factory methods should be preferred.
      Throws:
      IOException
    • LanguageServiceClient

      protected LanguageServiceClient(LanguageServiceStub stub)
  • Method Details

    • create

      public static final LanguageServiceClient create() throws IOException
      Constructs an instance of LanguageServiceClient with default settings.
      Throws:
      IOException
    • create

      public static final LanguageServiceClient create(LanguageServiceSettings settings) throws IOException
      Constructs an instance of LanguageServiceClient, using the given settings. The channels are created based on the settings passed in, or defaults for any settings that are not set.
      Throws:
      IOException
    • create

      public static final LanguageServiceClient create(LanguageServiceStub stub)
      Constructs an instance of LanguageServiceClient, using the given stub for making calls. This is for advanced usage - prefer using create(LanguageServiceSettings).
    • getSettings

      public final LanguageServiceSettings getSettings()
    • getStub

      public LanguageServiceStub getStub()
    • analyzeSentiment

      public final AnalyzeSentimentResponse analyzeSentiment(Document document)
      Analyzes the sentiment of the provided text.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         AnalyzeSentimentResponse response = languageServiceClient.analyzeSentiment(document);
       }
       
      Parameters:
      document - Required. Input document.
      Throws:
      ApiException - if the remote call fails
    • analyzeSentiment

      public final AnalyzeSentimentResponse analyzeSentiment(Document document, EncodingType encodingType)
      Analyzes the sentiment of the provided text.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         EncodingType encodingType = EncodingType.forNumber(0);
         AnalyzeSentimentResponse response =
             languageServiceClient.analyzeSentiment(document, encodingType);
       }
       
      Parameters:
      document - Required. Input document.
      encodingType - The encoding type used by the API to calculate sentence offsets for the sentence sentiment.
      Throws:
      ApiException - if the remote call fails
    • analyzeSentiment

      public final AnalyzeSentimentResponse analyzeSentiment(AnalyzeSentimentRequest request)
      Analyzes the sentiment of the provided text.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeSentimentRequest request =
             AnalyzeSentimentRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         AnalyzeSentimentResponse response = languageServiceClient.analyzeSentiment(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • analyzeSentimentCallable

      public final UnaryCallable<AnalyzeSentimentRequest,AnalyzeSentimentResponse> analyzeSentimentCallable()
      Analyzes the sentiment of the provided text.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeSentimentRequest request =
             AnalyzeSentimentRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         ApiFuture<AnalyzeSentimentResponse> future =
             languageServiceClient.analyzeSentimentCallable().futureCall(request);
         // Do something.
         AnalyzeSentimentResponse response = future.get();
       }
       
    • analyzeEntities

      public final AnalyzeEntitiesResponse analyzeEntities(Document document)
      Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         AnalyzeEntitiesResponse response = languageServiceClient.analyzeEntities(document);
       }
       
      Parameters:
      document - Required. Input document.
      Throws:
      ApiException - if the remote call fails
    • analyzeEntities

      public final AnalyzeEntitiesResponse analyzeEntities(Document document, EncodingType encodingType)
      Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         EncodingType encodingType = EncodingType.forNumber(0);
         AnalyzeEntitiesResponse response =
             languageServiceClient.analyzeEntities(document, encodingType);
       }
       
      Parameters:
      document - Required. Input document.
      encodingType - The encoding type used by the API to calculate offsets.
      Throws:
      ApiException - if the remote call fails
    • analyzeEntities

      public final AnalyzeEntitiesResponse analyzeEntities(AnalyzeEntitiesRequest request)
      Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeEntitiesRequest request =
             AnalyzeEntitiesRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         AnalyzeEntitiesResponse response = languageServiceClient.analyzeEntities(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • analyzeEntitiesCallable

      public final UnaryCallable<AnalyzeEntitiesRequest,AnalyzeEntitiesResponse> analyzeEntitiesCallable()
      Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeEntitiesRequest request =
             AnalyzeEntitiesRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         ApiFuture<AnalyzeEntitiesResponse> future =
             languageServiceClient.analyzeEntitiesCallable().futureCall(request);
         // Do something.
         AnalyzeEntitiesResponse response = future.get();
       }
       
    • analyzeEntitySentiment

      public final AnalyzeEntitySentimentResponse analyzeEntitySentiment(Document document)
      Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         AnalyzeEntitySentimentResponse response =
             languageServiceClient.analyzeEntitySentiment(document);
       }
       
      Parameters:
      document - Required. Input document.
      Throws:
      ApiException - if the remote call fails
    • analyzeEntitySentiment

      public final AnalyzeEntitySentimentResponse analyzeEntitySentiment(Document document, EncodingType encodingType)
      Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         EncodingType encodingType = EncodingType.forNumber(0);
         AnalyzeEntitySentimentResponse response =
             languageServiceClient.analyzeEntitySentiment(document, encodingType);
       }
       
      Parameters:
      document - Required. Input document.
      encodingType - The encoding type used by the API to calculate offsets.
      Throws:
      ApiException - if the remote call fails
    • analyzeEntitySentiment

      public final AnalyzeEntitySentimentResponse analyzeEntitySentiment(AnalyzeEntitySentimentRequest request)
      Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeEntitySentimentRequest request =
             AnalyzeEntitySentimentRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         AnalyzeEntitySentimentResponse response =
             languageServiceClient.analyzeEntitySentiment(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • analyzeEntitySentimentCallable

      public final UnaryCallable<AnalyzeEntitySentimentRequest,AnalyzeEntitySentimentResponse> analyzeEntitySentimentCallable()
      Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeEntitySentimentRequest request =
             AnalyzeEntitySentimentRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         ApiFuture<AnalyzeEntitySentimentResponse> future =
             languageServiceClient.analyzeEntitySentimentCallable().futureCall(request);
         // Do something.
         AnalyzeEntitySentimentResponse response = future.get();
       }
       
    • analyzeSyntax

      public final AnalyzeSyntaxResponse analyzeSyntax(Document document)
      Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         AnalyzeSyntaxResponse response = languageServiceClient.analyzeSyntax(document);
       }
       
      Parameters:
      document - Required. Input document.
      Throws:
      ApiException - if the remote call fails
    • analyzeSyntax

      public final AnalyzeSyntaxResponse analyzeSyntax(Document document, EncodingType encodingType)
      Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         EncodingType encodingType = EncodingType.forNumber(0);
         AnalyzeSyntaxResponse response = languageServiceClient.analyzeSyntax(document, encodingType);
       }
       
      Parameters:
      document - Required. Input document.
      encodingType - The encoding type used by the API to calculate offsets.
      Throws:
      ApiException - if the remote call fails
    • analyzeSyntax

      public final AnalyzeSyntaxResponse analyzeSyntax(AnalyzeSyntaxRequest request)
      Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeSyntaxRequest request =
             AnalyzeSyntaxRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         AnalyzeSyntaxResponse response = languageServiceClient.analyzeSyntax(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • analyzeSyntaxCallable

      public final UnaryCallable<AnalyzeSyntaxRequest,AnalyzeSyntaxResponse> analyzeSyntaxCallable()
      Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnalyzeSyntaxRequest request =
             AnalyzeSyntaxRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         ApiFuture<AnalyzeSyntaxResponse> future =
             languageServiceClient.analyzeSyntaxCallable().futureCall(request);
         // Do something.
         AnalyzeSyntaxResponse response = future.get();
       }
       
    • classifyText

      public final ClassifyTextResponse classifyText(Document document)
      Classifies a document into categories.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         ClassifyTextResponse response = languageServiceClient.classifyText(document);
       }
       
      Parameters:
      document - Required. Input document.
      Throws:
      ApiException - if the remote call fails
    • classifyText

      public final ClassifyTextResponse classifyText(ClassifyTextRequest request)
      Classifies a document into categories.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         ClassifyTextRequest request =
             ClassifyTextRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setClassificationModelOptions(ClassificationModelOptions.newBuilder().build())
                 .build();
         ClassifyTextResponse response = languageServiceClient.classifyText(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • classifyTextCallable

      public final UnaryCallable<ClassifyTextRequest,ClassifyTextResponse> classifyTextCallable()
      Classifies a document into categories.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         ClassifyTextRequest request =
             ClassifyTextRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setClassificationModelOptions(ClassificationModelOptions.newBuilder().build())
                 .build();
         ApiFuture<ClassifyTextResponse> future =
             languageServiceClient.classifyTextCallable().futureCall(request);
         // Do something.
         ClassifyTextResponse response = future.get();
       }
       
    • moderateText

      public final ModerateTextResponse moderateText(Document document)
      Moderates a document for harmful and sensitive categories.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         ModerateTextResponse response = languageServiceClient.moderateText(document);
       }
       
      Parameters:
      document - Required. Input document.
      Throws:
      ApiException - if the remote call fails
    • moderateText

      public final ModerateTextResponse moderateText(ModerateTextRequest request)
      Moderates a document for harmful and sensitive categories.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         ModerateTextRequest request =
             ModerateTextRequest.newBuilder().setDocument(Document.newBuilder().build()).build();
         ModerateTextResponse response = languageServiceClient.moderateText(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • moderateTextCallable

      public final UnaryCallable<ModerateTextRequest,ModerateTextResponse> moderateTextCallable()
      Moderates a document for harmful and sensitive categories.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         ModerateTextRequest request =
             ModerateTextRequest.newBuilder().setDocument(Document.newBuilder().build()).build();
         ApiFuture<ModerateTextResponse> future =
             languageServiceClient.moderateTextCallable().futureCall(request);
         // Do something.
         ModerateTextResponse response = future.get();
       }
       
    • annotateText

      public final AnnotateTextResponse annotateText(Document document, AnnotateTextRequest.Features features)
      A convenience method that provides all syntax, sentiment, entity, and classification features in one call.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         AnnotateTextRequest.Features features = AnnotateTextRequest.Features.newBuilder().build();
         AnnotateTextResponse response = languageServiceClient.annotateText(document, features);
       }
       
      Parameters:
      document - Required. Input document.
      features - Required. The enabled features.
      Throws:
      ApiException - if the remote call fails
    • annotateText

      public final AnnotateTextResponse annotateText(Document document, AnnotateTextRequest.Features features, EncodingType encodingType)
      A convenience method that provides all syntax, sentiment, entity, and classification features in one call.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         Document document = Document.newBuilder().build();
         AnnotateTextRequest.Features features = AnnotateTextRequest.Features.newBuilder().build();
         EncodingType encodingType = EncodingType.forNumber(0);
         AnnotateTextResponse response =
             languageServiceClient.annotateText(document, features, encodingType);
       }
       
      Parameters:
      document - Required. Input document.
      features - Required. The enabled features.
      encodingType - The encoding type used by the API to calculate offsets.
      Throws:
      ApiException - if the remote call fails
    • annotateText

      public final AnnotateTextResponse annotateText(AnnotateTextRequest request)
      A convenience method that provides all syntax, sentiment, entity, and classification features in one call.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnnotateTextRequest request =
             AnnotateTextRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setFeatures(AnnotateTextRequest.Features.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         AnnotateTextResponse response = languageServiceClient.annotateText(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • annotateTextCallable

      public final UnaryCallable<AnnotateTextRequest,AnnotateTextResponse> annotateTextCallable()
      A convenience method that provides all syntax, sentiment, entity, and classification features in one call.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
         AnnotateTextRequest request =
             AnnotateTextRequest.newBuilder()
                 .setDocument(Document.newBuilder().build())
                 .setFeatures(AnnotateTextRequest.Features.newBuilder().build())
                 .setEncodingType(EncodingType.forNumber(0))
                 .build();
         ApiFuture<AnnotateTextResponse> future =
             languageServiceClient.annotateTextCallable().futureCall(request);
         // Do something.
         AnnotateTextResponse response = future.get();
       }
       
    • close

      public final void close()
      Specified by:
      close in interface AutoCloseable
    • shutdown

      public void shutdown()
      Specified by:
      shutdown in interface BackgroundResource
    • isShutdown

      public boolean isShutdown()
      Specified by:
      isShutdown in interface BackgroundResource
    • isTerminated

      public boolean isTerminated()
      Specified by:
      isTerminated in interface BackgroundResource
    • shutdownNow

      public void shutdownNow()
      Specified by:
      shutdownNow in interface BackgroundResource
    • awaitTermination

      public boolean awaitTermination(long duration, TimeUnit unit) throws InterruptedException
      Specified by:
      awaitTermination in interface BackgroundResource
      Throws:
      InterruptedException