Class LanguageServiceClient
- All Implemented Interfaces:
BackgroundResource,AutoCloseable
This class provides the ability to make remote calls to the backing service through method calls that map to API methods. Sample code to get started:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) {
Document document = Document.newBuilder().build();
AnalyzeSentimentResponse response = languageServiceClient.analyzeSentiment(document);
}
Note: close() needs to be called on the LanguageServiceClient object to clean up resources such as threads. In the example above, try-with-resources is used, which automatically calls close().
| Method | Description | Method Variants |
|---|---|---|
AnalyzeSentiment |
Analyzes the sentiment of the provided text. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
AnalyzeEntities |
Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
AnalyzeEntitySentiment |
Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
AnalyzeSyntax |
Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
ClassifyText |
Classifies a document into categories. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
ModerateText |
Moderates a document for harmful and sensitive categories. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
AnnotateText |
A convenience method that provides all syntax, sentiment, entity, and classification features in one call. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
See the individual methods for example code.
Many parameters require resource names to be formatted in a particular way. To assist with these names, this class includes a format method for each type of name, and additionally a parse method to extract the individual identifiers contained within names that are returned.
This class can be customized by passing in a custom instance of LanguageServiceSettings to create(). For example:
To customize credentials:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
LanguageServiceSettings languageServiceSettings =
LanguageServiceSettings.newBuilder()
.setCredentialsProvider(FixedCredentialsProvider.create(myCredentials))
.build();
LanguageServiceClient languageServiceClient =
LanguageServiceClient.create(languageServiceSettings);
To customize the endpoint:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
LanguageServiceSettings languageServiceSettings =
LanguageServiceSettings.newBuilder().setEndpoint(myEndpoint).build();
LanguageServiceClient languageServiceClient =
LanguageServiceClient.create(languageServiceSettings);
To use REST (HTTP1.1/JSON) transport (instead of gRPC) for sending and receiving requests over the wire:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
LanguageServiceSettings languageServiceSettings =
LanguageServiceSettings.newHttpJsonBuilder().build();
LanguageServiceClient languageServiceClient =
LanguageServiceClient.create(languageServiceSettings);
Please refer to the GitHub repository's samples for more quickstart code snippets.
-
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedLanguageServiceClient(LanguageServiceSettings settings) Constructs an instance of LanguageServiceClient, using the given settings.protected -
Method Summary
Modifier and TypeMethodDescriptionfinal AnalyzeEntitiesResponseanalyzeEntities(AnalyzeEntitiesRequest request) Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.final AnalyzeEntitiesResponseanalyzeEntities(Document document) Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.final AnalyzeEntitiesResponseanalyzeEntities(Document document, EncodingType encodingType) Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.analyzeEntitySentiment(Document document) Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.analyzeEntitySentiment(Document document, EncodingType encodingType) Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.final AnalyzeSentimentResponseanalyzeSentiment(AnalyzeSentimentRequest request) Analyzes the sentiment of the provided text.final AnalyzeSentimentResponseanalyzeSentiment(Document document) Analyzes the sentiment of the provided text.final AnalyzeSentimentResponseanalyzeSentiment(Document document, EncodingType encodingType) Analyzes the sentiment of the provided text.Analyzes the sentiment of the provided text.final AnalyzeSyntaxResponseanalyzeSyntax(AnalyzeSyntaxRequest request) Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.final AnalyzeSyntaxResponseanalyzeSyntax(Document document) Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.final AnalyzeSyntaxResponseanalyzeSyntax(Document document, EncodingType encodingType) Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.final AnnotateTextResponseannotateText(AnnotateTextRequest request) A convenience method that provides all syntax, sentiment, entity, and classification features in one call.final AnnotateTextResponseannotateText(Document document, AnnotateTextRequest.Features features) A convenience method that provides all syntax, sentiment, entity, and classification features in one call.final AnnotateTextResponseannotateText(Document document, AnnotateTextRequest.Features features, EncodingType encodingType) A convenience method that provides all syntax, sentiment, entity, and classification features in one call.A convenience method that provides all syntax, sentiment, entity, and classification features in one call.booleanawaitTermination(long duration, TimeUnit unit) final ClassifyTextResponseclassifyText(ClassifyTextRequest request) Classifies a document into categories.final ClassifyTextResponseclassifyText(Document document) Classifies a document into categories.Classifies a document into categories.final voidclose()static final LanguageServiceClientcreate()Constructs an instance of LanguageServiceClient with default settings.static final LanguageServiceClientcreate(LanguageServiceSettings settings) Constructs an instance of LanguageServiceClient, using the given settings.static final LanguageServiceClientcreate(LanguageServiceStub stub) Constructs an instance of LanguageServiceClient, using the given stub for making calls.final LanguageServiceSettingsgetStub()booleanbooleanfinal ModerateTextResponsemoderateText(Document document) Moderates a document for harmful and sensitive categories.final ModerateTextResponsemoderateText(ModerateTextRequest request) Moderates a document for harmful and sensitive categories.Moderates a document for harmful and sensitive categories.voidshutdown()void
-
Constructor Details
-
LanguageServiceClient
Constructs an instance of LanguageServiceClient, using the given settings. This is protected so that it is easy to make a subclass, but otherwise, the static factory methods should be preferred.- Throws:
IOException
-
LanguageServiceClient
-
-
Method Details
-
create
Constructs an instance of LanguageServiceClient with default settings.- Throws:
IOException
-
create
public static final LanguageServiceClient create(LanguageServiceSettings settings) throws IOException Constructs an instance of LanguageServiceClient, using the given settings. The channels are created based on the settings passed in, or defaults for any settings that are not set.- Throws:
IOException
-
create
Constructs an instance of LanguageServiceClient, using the given stub for making calls. This is for advanced usage - prefer using create(LanguageServiceSettings). -
getSettings
-
getStub
-
analyzeSentiment
Analyzes the sentiment of the provided text.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); AnalyzeSentimentResponse response = languageServiceClient.analyzeSentiment(document); }- Parameters:
document- Required. Input document.- Throws:
ApiException- if the remote call fails
-
analyzeSentiment
public final AnalyzeSentimentResponse analyzeSentiment(Document document, EncodingType encodingType) Analyzes the sentiment of the provided text.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); EncodingType encodingType = EncodingType.forNumber(0); AnalyzeSentimentResponse response = languageServiceClient.analyzeSentiment(document, encodingType); }- Parameters:
document- Required. Input document.encodingType- The encoding type used by the API to calculate sentence offsets for the sentence sentiment.- Throws:
ApiException- if the remote call fails
-
analyzeSentiment
Analyzes the sentiment of the provided text.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeSentimentRequest request = AnalyzeSentimentRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); AnalyzeSentimentResponse response = languageServiceClient.analyzeSentiment(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
analyzeSentimentCallable
public final UnaryCallable<AnalyzeSentimentRequest,AnalyzeSentimentResponse> analyzeSentimentCallable()Analyzes the sentiment of the provided text.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeSentimentRequest request = AnalyzeSentimentRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); ApiFuture<AnalyzeSentimentResponse> future = languageServiceClient.analyzeSentimentCallable().futureCall(request); // Do something. AnalyzeSentimentResponse response = future.get(); } -
analyzeEntities
Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); AnalyzeEntitiesResponse response = languageServiceClient.analyzeEntities(document); }- Parameters:
document- Required. Input document.- Throws:
ApiException- if the remote call fails
-
analyzeEntities
Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); EncodingType encodingType = EncodingType.forNumber(0); AnalyzeEntitiesResponse response = languageServiceClient.analyzeEntities(document, encodingType); }- Parameters:
document- Required. Input document.encodingType- The encoding type used by the API to calculate offsets.- Throws:
ApiException- if the remote call fails
-
analyzeEntities
Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeEntitiesRequest request = AnalyzeEntitiesRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); AnalyzeEntitiesResponse response = languageServiceClient.analyzeEntities(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
analyzeEntitiesCallable
public final UnaryCallable<AnalyzeEntitiesRequest,AnalyzeEntitiesResponse> analyzeEntitiesCallable()Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeEntitiesRequest request = AnalyzeEntitiesRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); ApiFuture<AnalyzeEntitiesResponse> future = languageServiceClient.analyzeEntitiesCallable().futureCall(request); // Do something. AnalyzeEntitiesResponse response = future.get(); } -
analyzeEntitySentiment
Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); AnalyzeEntitySentimentResponse response = languageServiceClient.analyzeEntitySentiment(document); }- Parameters:
document- Required. Input document.- Throws:
ApiException- if the remote call fails
-
analyzeEntitySentiment
public final AnalyzeEntitySentimentResponse analyzeEntitySentiment(Document document, EncodingType encodingType) Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); EncodingType encodingType = EncodingType.forNumber(0); AnalyzeEntitySentimentResponse response = languageServiceClient.analyzeEntitySentiment(document, encodingType); }- Parameters:
document- Required. Input document.encodingType- The encoding type used by the API to calculate offsets.- Throws:
ApiException- if the remote call fails
-
analyzeEntitySentiment
public final AnalyzeEntitySentimentResponse analyzeEntitySentiment(AnalyzeEntitySentimentRequest request) Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeEntitySentimentRequest request = AnalyzeEntitySentimentRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); AnalyzeEntitySentimentResponse response = languageServiceClient.analyzeEntitySentiment(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
analyzeEntitySentimentCallable
public final UnaryCallable<AnalyzeEntitySentimentRequest,AnalyzeEntitySentimentResponse> analyzeEntitySentimentCallable()Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1beta2.LanguageService.AnalyzeEntities] in the text and analyzes sentiment associated with each entity and its mentions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeEntitySentimentRequest request = AnalyzeEntitySentimentRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); ApiFuture<AnalyzeEntitySentimentResponse> future = languageServiceClient.analyzeEntitySentimentCallable().futureCall(request); // Do something. AnalyzeEntitySentimentResponse response = future.get(); } -
analyzeSyntax
Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); AnalyzeSyntaxResponse response = languageServiceClient.analyzeSyntax(document); }- Parameters:
document- Required. Input document.- Throws:
ApiException- if the remote call fails
-
analyzeSyntax
Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); EncodingType encodingType = EncodingType.forNumber(0); AnalyzeSyntaxResponse response = languageServiceClient.analyzeSyntax(document, encodingType); }- Parameters:
document- Required. Input document.encodingType- The encoding type used by the API to calculate offsets.- Throws:
ApiException- if the remote call fails
-
analyzeSyntax
Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeSyntaxRequest request = AnalyzeSyntaxRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); AnalyzeSyntaxResponse response = languageServiceClient.analyzeSyntax(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
analyzeSyntaxCallable
Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnalyzeSyntaxRequest request = AnalyzeSyntaxRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); ApiFuture<AnalyzeSyntaxResponse> future = languageServiceClient.analyzeSyntaxCallable().futureCall(request); // Do something. AnalyzeSyntaxResponse response = future.get(); } -
classifyText
Classifies a document into categories.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); ClassifyTextResponse response = languageServiceClient.classifyText(document); }- Parameters:
document- Required. Input document.- Throws:
ApiException- if the remote call fails
-
classifyText
Classifies a document into categories.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { ClassifyTextRequest request = ClassifyTextRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setClassificationModelOptions(ClassificationModelOptions.newBuilder().build()) .build(); ClassifyTextResponse response = languageServiceClient.classifyText(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
classifyTextCallable
Classifies a document into categories.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { ClassifyTextRequest request = ClassifyTextRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setClassificationModelOptions(ClassificationModelOptions.newBuilder().build()) .build(); ApiFuture<ClassifyTextResponse> future = languageServiceClient.classifyTextCallable().futureCall(request); // Do something. ClassifyTextResponse response = future.get(); } -
moderateText
Moderates a document for harmful and sensitive categories.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); ModerateTextResponse response = languageServiceClient.moderateText(document); }- Parameters:
document- Required. Input document.- Throws:
ApiException- if the remote call fails
-
moderateText
Moderates a document for harmful and sensitive categories.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { ModerateTextRequest request = ModerateTextRequest.newBuilder().setDocument(Document.newBuilder().build()).build(); ModerateTextResponse response = languageServiceClient.moderateText(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
moderateTextCallable
Moderates a document for harmful and sensitive categories.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { ModerateTextRequest request = ModerateTextRequest.newBuilder().setDocument(Document.newBuilder().build()).build(); ApiFuture<ModerateTextResponse> future = languageServiceClient.moderateTextCallable().futureCall(request); // Do something. ModerateTextResponse response = future.get(); } -
annotateText
public final AnnotateTextResponse annotateText(Document document, AnnotateTextRequest.Features features) A convenience method that provides all syntax, sentiment, entity, and classification features in one call.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); AnnotateTextRequest.Features features = AnnotateTextRequest.Features.newBuilder().build(); AnnotateTextResponse response = languageServiceClient.annotateText(document, features); }- Parameters:
document- Required. Input document.features- Required. The enabled features.- Throws:
ApiException- if the remote call fails
-
annotateText
public final AnnotateTextResponse annotateText(Document document, AnnotateTextRequest.Features features, EncodingType encodingType) A convenience method that provides all syntax, sentiment, entity, and classification features in one call.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { Document document = Document.newBuilder().build(); AnnotateTextRequest.Features features = AnnotateTextRequest.Features.newBuilder().build(); EncodingType encodingType = EncodingType.forNumber(0); AnnotateTextResponse response = languageServiceClient.annotateText(document, features, encodingType); }- Parameters:
document- Required. Input document.features- Required. The enabled features.encodingType- The encoding type used by the API to calculate offsets.- Throws:
ApiException- if the remote call fails
-
annotateText
A convenience method that provides all syntax, sentiment, entity, and classification features in one call.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnnotateTextRequest request = AnnotateTextRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setFeatures(AnnotateTextRequest.Features.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); AnnotateTextResponse response = languageServiceClient.annotateText(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
annotateTextCallable
A convenience method that provides all syntax, sentiment, entity, and classification features in one call.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (LanguageServiceClient languageServiceClient = LanguageServiceClient.create()) { AnnotateTextRequest request = AnnotateTextRequest.newBuilder() .setDocument(Document.newBuilder().build()) .setFeatures(AnnotateTextRequest.Features.newBuilder().build()) .setEncodingType(EncodingType.forNumber(0)) .build(); ApiFuture<AnnotateTextResponse> future = languageServiceClient.annotateTextCallable().futureCall(request); // Do something. AnnotateTextResponse response = future.get(); } -
close
public final void close()- Specified by:
closein interfaceAutoCloseable
-
shutdown
public void shutdown()- Specified by:
shutdownin interfaceBackgroundResource
-
isShutdown
public boolean isShutdown()- Specified by:
isShutdownin interfaceBackgroundResource
-
isTerminated
public boolean isTerminated()- Specified by:
isTerminatedin interfaceBackgroundResource
-
shutdownNow
public void shutdownNow()- Specified by:
shutdownNowin interfaceBackgroundResource
-
awaitTermination
- Specified by:
awaitTerminationin interfaceBackgroundResource- Throws:
InterruptedException
-